@@ -82,7 +82,7 @@ struct driver
 
 static const struct driver drivers[] =
 {
-	{ "cu3088", CHANNEL_TYPE_CU3088_ALL },
+	{ "ctcm", CHANNEL_TYPE_CU3088_ALL },
 	{ "qeth", CHANNEL_TYPE_QETH },
 };
 
